# Verity SDK

This is the official Python SDK for Evernym's Verity application. 

This procedure shows you how to set up your Python development environment to use the Verity SDK. 

## Prerequisites
Install the following items:
* `libindy` -- Install a stable version. Follow the instructions on the 
[indy-sdk Github Project Page](https://github.com/hyperledger/indy-sdk#installing-the-sdk).

## Get Latest Python Verity SDK
See [pypi project](https://pypi.org/project/verity-sdk/) page to find the latest release. 

Install verity-sdk via pip:
```sh
pip install verity-sdk
```

## Documentation
**API Documentation**:
* [0.4.0](https://developer.evernym.com/doc/python/0.4.0/index.html)

## Develop the Python Verity SDK

### Development Prerequisites
* `Python3` -- Follow the instructions on the [Python3 website](https://www.python.org/downloads/)

### Pip Install
Install dependencies:
```sh
pip install -r requirements.txt
```

### Hack away